BuiltinFunctionSurfaceEntry

Struct BuiltinFunctionSurfaceEntry 

pub struct BuiltinFunctionSurfaceEntry {
    pub name: String,
    pub num_args: i32,
    pub family: BuiltinFunctionFamily,
    pub class: BuiltinFunctionClass,
    pub is_alias: bool,
    pub surface_id: &'static str,
}
Runtime-authoritative description of one built-in function registration.

Fields

name: String

Lowercase SQL function name as exposed by the runtime registry.

num_args: i32

Declared arity, or -1 for variadic registrations.

family: BuiltinFunctionFamily

Top-level function family.

class: BuiltinFunctionClass

Track-E parity classification bucket.

is_alias: bool

Whether this entry is an alternate spelling over another runtime entry.

surface_id: &'static str

Canonical parity surface identifier for this function family.