pub struct CollationRegistry { /* private fields */ }Expand description
Registry for collation functions, keyed by case-insensitive name.
Pre-populated with the three built-in collations: BINARY, NOCASE, RTRIM.
Custom collations can be registered via CollationRegistry::register.
Implementations
Sourceimpl CollationRegistry
impl CollationRegistry
Sourcepub fn register<C: CollationFunction + 'static>(
&mut self,
collation: C,
) -> Option<Arc<dyn CollationFunction>>
pub fn register<C: CollationFunction + 'static>( &mut self, collation: C, ) -> Option<Arc<dyn CollationFunction>>
Register a custom collation. Returns the previous collation with the same name if one existed (overwrites).
Collation names are case-insensitive.
Sourcepub fn find(&self, name: &str) -> Option<Arc<dyn CollationFunction>>
pub fn find(&self, name: &str) -> Option<Arc<dyn CollationFunction>>
Look up a collation by name (case-insensitive).
Returns None if no collation with the given name is registered.