ShadowTablePolicy

Struct ShadowTablePolicy 

pub struct ShadowTablePolicy {
    pub kind: ShadowTableKind,
}
Policy returned by a module when the core asks whether a table name is a shadow table of a virtual table instance.

Fields

kind: ShadowTableKind

Whether the table is ordinary or shadow-owned.

Implementations

Source

impl ShadowTablePolicy

pub const fn ordinary() -> Self

Policy for an ordinary, non-shadow table.

pub const fn owned_shadow() -> Self

Policy for a module-owned shadow table.

pub const fn is_shadow(self) -> bool

Whether the table is module-owned shadow state.