pub struct ShadowTablePolicy {
pub kind: ShadowTableKind,
}Expand description
Policy returned by a module when the core asks whether a table name is a shadow table of a virtual table instance.
Fields
kind: ShadowTableKindWhether the table is ordinary or shadow-owned.
Implementations